import java.io.Serializable;

/**
 * Simple example complex type to demonstrate serialization over RMI.
 * 
 * {@link http://java.sun.com/developer/technicalArticles/Programming/serialization/}
 * 
 * @author Daniel Bimschas, ITM Universitt zu Lbeck
 * 
 */
public class Person implements Serializable {

	/**
	 * Provide a class version to make sure that, upon de-serialization, the
	 * correct version is used.
	 * 
	 * {@link http://java.sun.com/j2se/1.5.0/docs/api/java/io/Serializable.html}
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Static fields are not serialized as they're properties of the class, not
	 * of the class instance (!)
	 */
	public static final String SOME_CONSTANT_VALUE = "SomeConstantValue";

	/**
	 * Some example property that will be part of the serialization.
	 */
	private String name;

	/**
	 * Transient fields are not serialized. They're subject to frequent change
	 * and not defining the state of the object itself.
	 */
	private transient Thread personsThread;

	public Person(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	public Thread getPersonsThread() {
		return personsThread;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void setPersonsThread(Thread personsThread) {
		this.personsThread = personsThread;
	}

}
