import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Example interface demonstrating how to provide remote objects for Java RMI.
 * 
 * Rules: all remote objects must implement {@link Remote} and every
 * method that can be called remotely must throw an {@link RemoteException}.
 * 
 * @author Daniel Bimschas, ITM Universitt zu Lbeck
 * 
 */
public interface ServerTime extends Remote {

	/**
	 * Returns the local time on the server.
	 * 
	 * @return
	 * @throws RemoteException
	 */
	long getServerTime() throws RemoteException;

	/**
	 * An example method to demonstrate the usage of self-defined complex types
	 * to be passed over in Java RMI remote method calls.
	 * 
	 * @param person
	 * @return
	 * @throws RemoteException
	 */
	String helloWorld(Person person) throws RemoteException;

}
