import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.text.MessageFormat;

/**
 * An example implementation of a client for the remote object of type
 * {@link ServerTime}.
 * 
 * @author Daniel Bimschas, ITM Universitt zu Lbeck
 * 
 */
public class ServerTimeClient {

	public static void main(String[] args) {

		try {

			// get remote object reference
			Registry registry = LocateRegistry.getRegistry(Registry.REGISTRY_PORT);
			ServerTime remoteService = (ServerTime) registry.lookup("ServerTime");

			long before, after;
			String msg;

			// query for server time
			before = System.currentTimeMillis();
			long serverTime = remoteService.getServerTime();
			after = System.currentTimeMillis();

			// print server time
			msg = MessageFormat.format("Zeit auf Server: {0,date,full} {0,time,long}, time needed: {1} ms",
					serverTime, after - before);
			System.out.println(msg);

			// query for hello world
			before = System.currentTimeMillis();
			String hello = remoteService.helloWorld(new Person("Zaphod Beeblebrox"));
			after = System.currentTimeMillis();

			// print hello world
			msg = MessageFormat.format("Reply to helloWorld(...): {0}, time needed: {1} ms", hello,
					after - before);
			System.out.println(msg);

		} catch (Exception e) {
			System.err.println("ServerTimeClient exception:");
			e.printStackTrace();
		}

	}

}
