import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.rmi.server.UnicastRemoteObject;

/**
 * An example implementation for the RMI server of type {@link ServerTime}.
 * 
 * @author Daniel Bimschas, ITM Universitt zu Lbeck
 * 
 */
public class ServerTimeServer implements ServerTime {

	public static void main(String[] args) throws IOException {

		try {

			// create an instance of the server
			ServerTime serverTimeImplInstance = new ServerTimeServer();

			// create a remote object stub that can be registered with RMI
			// registry
			ServerTime stub = (ServerTime) UnicastRemoteObject.exportObject(serverTimeImplInstance,
					Registry.REGISTRY_PORT);

			// locate registry
			Registry registry = LocateRegistry.createRegistry(Registry.REGISTRY_PORT);

			// bind server to RMI registry under the name of "ServerTime"
			registry.bind("ServerTime", stub);

			System.out.println("ServerTime bound");

		} catch (Exception e) {
			System.err.println("ServerTime exception:");
			e.printStackTrace();
			System.exit(1);
		}

		while (true) {

			System.out.print("Enter 'exit' to quit: ");

			BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
			if ("exit".equals(reader.readLine())) {
				System.exit(0);
			}

		}

	}

	@Override
	public long getServerTime() throws RemoteException {
		return System.currentTimeMillis();
	}

	@Override
	public String helloWorld(Person person) throws RemoteException {
		return "hello " + person.getName();
	}

}
